@@ -934,6 +934,13 @@ def cor_time(x=None, y=None):
     x.run()
     y.run()
 
+    df = (x.contents.loc[:,["variable", "data_type"]].rename(columns = {"data_type":"type1"})
+        .merge(y.contents.loc[:,["variable", "data_type"]].rename(columns = {"data_type":"type2"}))
+        .query("type1 != type2")
+        )
+    if len(df) > 0:
+        raise ValueError("Datasets have different data types. Please unify them using set_precision")
+
     if len(x) > 1 or len(y) > 1:
         raise TypeError("cor_time only accepts single file datasets!")
 
@@ -995,6 +1002,13 @@ def cor_space(x=None, y=None):
     x.run()
     y.run()
 
+    df = (x.contents.loc[:,["variable", "data_type"]].rename(columns = {"data_type":"type1"})
+        .merge(y.contents.loc[:,["variable", "data_type"]].rename(columns = {"data_type":"type2"}))
+        .query("type1 != type2")
+        )
+    if len(df) > 0:
+        raise ValueError("Datasets have different data types. Please unify them using set_precision")
+
     if len(x) > 1 or len(y) > 1:
         raise TypeError("cor_time only accepts single file datasets!")
 
@@ -1767,6 +1781,7 @@ class DataSet(object):
     from nctoolkit.zonals import zonal_min
     from nctoolkit.zonals import zonal_max
     from nctoolkit.zonals import zonal_range
+    from nctoolkit.zonals import zonal_sum
 
     # Deprecated methods
     from nctoolkit.deprecated import set_missing
