@@ -97,6 +97,7 @@ funs = [
     "int",
     "float",
     "log10",
+    "thickness"
 ]
 
 translation = dict()
@@ -105,6 +106,7 @@ for ff in funs:
         translation[ff] = ff
 
 translation["int"] = "int"
+#translation["deltaz"] = "cdeltaz"
 translation["float"] = "float"
 
 translation["arcsin"] = "asin"
@@ -472,6 +474,12 @@ def assign(self, drop=False, **kwargs):
         if " = = False" in start:
             start = start.replace(" = = False", " < 1")
 
+        version = session_info["cdo"]
+        if version_below(version, "2.1.0"):
+            translation["thickness"] = "cdeltaz"
+        else:
+            translation["thickness"] = "cthickness"
+
         for x in start.split(" "):
             if "(" in x:
                 x_fun = x.split("(")[0]
@@ -501,9 +509,10 @@ def assign(self, drop=False, **kwargs):
                         if x_fun in translation.keys():
                             x_term = between_brackets(x)
                             if (f"{lambda_value}." in x_term) is False:
-                                raise ValueError(
-                                    f"Error for {x}: nctoolkit functions must take dataset variables as args!"
-                                )
+                                if x_fun not in ["timestep"]:
+                                    raise ValueError(
+                                        f"Error for {x}: nctoolkit functions must take dataset variables as args!"
+                                    )
                             if x_fun == "timestep":
                                 start = start.replace(x, "(" + x + "-1)")
                             if x_fun in ["cell_area", "longitude", "latitude"]:
