@@ -10,6 +10,7 @@ from nctoolkit.runthis import run_this, run_cdo
 from nctoolkit.temp_file import temp_file
 from nctoolkit.session import append_safe
 from nctoolkit.session import remove_safe
+from nctoolkit.utils import version_above, cdo_version
 
 
 def bottom(self):
@@ -74,36 +75,69 @@ def top(self):
     run_this(cdo_command, self, output="ensemble")
 
 
-def vertical_interp(self, levels=None):
+def vertical_interp(self, levels=None, fixed = None, thickness = None):
     """
     Verticaly interpolate a dataset based on given vertical levels
     This is calculated for each time step and grid cell
+    Note: This requires consistent vertical levels in space. For the likes of sigma-coordinates,
+    please use to_zlevels.
 
     Parameters
     -------------
     levels : list, int or str
         list of vertical levels, for example depths for an ocean model, to vertically
         interpolate to. These must be floats or ints.
+    fixed : bool 
+        Define whether the vertical levels are the same in all spatial locations.
+        Set to True if they are, e.g. you have z-levels. If you have the likes of sigma-coordinates,
+        set this to True. 
+    thickness: str or Dataset
+        This must be supplied if fixed is False, otherwise vertical thickness cannot be known.
+        Option argument when vertical levels vary in space.
+        One of: a variable, in the dataset, which contains the variable thicknesses; a .nc file which contains
+        the thicknesses; or a Dataset that contains the thicknesses. Note: the .nc file or Dataset must only contain
+        one variable. Thickness should be in metres. Vertical interpolation will take the value from the mid-point of the level.
 
     Examples
     ------------
 
-    If you wanted to vertically interpolate a dataset to 5 and 10 metres, you would do the following:
+    If you wanted to vertically interpolate a dataset with spatially consistent vertical levels to 5 and 10 metres, you would do the following:
 
-    >>> ds.vertical_interp([5,10])
+    >>> ds.vertical_interp(levels = [5,10], fixed = True)
 
     This method is most useful for things like oceanic data, where you need to interpolate to certain depth levels.
     It will require that vertical levels are the same in every grid cell.
 
     """
 
+    if fixed is None:
+        if thickness is None:
+            raise ValueError("You must provide the fixed arg")
+
+    if fixed is False:
+        if thickness is None:
+            raise ValueError("Please provide thickness")
+
+    if type(fixed) is not bool:
+        if thickness is None:
+            raise TypeError("fixed must be a bool")
+
+    if thickness is not None:
+        fixed = False
+
+    if fixed is False:
+        self.to_zlevels(levels = levels, thickness = thickness)
+        return None
+
     if levels is None:
         raise ValueError("Please supply vertical depths")
 
     # first a quick fix for the case when there is only one vertical depth
 
     if (type(levels) == int) or (type(levels) == float):
-        levels = {levels}
+        levels = [levels]
+
+    #levels = [float(x) for x in levels]
 
     for vv in levels:
         if (type(vv) is not float) and (type(vv) is not int):
@@ -121,7 +155,7 @@ def vertstat(self, stat="mean"):
     run_this(cdo_command, self, output="ensemble")
 
 
-def vertical_mean(self, thickness=None, depth_range=None):
+def vertical_mean(self, thickness=None, depth_range=None, fixed = None):
     """
     Calculate the depth-averaged mean for each variable
     This is calculated for each time step and grid cell
@@ -129,20 +163,24 @@ def vertical_mean(self, thickness=None, depth_range=None):
     Optional parameters
     -------------
     thickness: str or Dataset
-        Only use when vertical levels vary in space
+        This mube be supplied when vertical levels vary in space, i.e. fixed=False.
         One of: a variable, in the dataset, which contains the variable thicknesses; a .nc file which contains
         the thicknesses; or a Dataset that contains the thicknesses. Note: the .nc file or Dataset must only contain
         one variable.
     depth_range: list
         Only use when vertical levels vary in space
         Set a depth range if desired. Should be of the form [min_depth, max_depth].
+    fixed : bool 
+        Define whether the vertical levels are the same in all spatial locations.
+        Set to True if they are, e.g. you have z-levels. If you have the likes of sigma-coordinates,
+        set this to True. 
 
     Examples
     ------------
 
-    If you wanted to vertical mean of every variable in a dataset, you would do this:
+    If you wanted to vertical mean of every variable in a dataset with consistent vertical levels, you would do this:
 
-    >>> ds.vertical_mean()
+    >>> ds.vertical_mean(fixed = True)
 
 
     This method will calculate the vertical mean weighted by the thickness of each cell. Note that
@@ -150,6 +188,14 @@ def vertical_mean(self, thickness=None, depth_range=None):
 
 
     """
+
+    if fixed is None and thickness is None:
+        raise ValueError("Please state if levels are fixed or provide thickness")
+
+    if fixed is False:
+        if thickness is None:
+            raise ValueError("Please provide thickness")
+
     if thickness is None and depth_range is None:
         vertstat(self, stat="mean")
         return None
@@ -219,7 +265,11 @@ def vertical_mean(self, thickness=None, depth_range=None):
     if drop_this is not None:
         self1.drop(variables = drop_this)
 
+    ds_thick.run()
+    self1.run()
     self1.multiply(ds_thick)
+    warnings.warn(message = "Assuming missing values are in the same grid cells in thickness and variable data. Modify thickness and re-run if they are not.")
+    self1.run()
     self1.vertical_sum()
     self1.run()
 
@@ -285,7 +335,7 @@ def vertical_range(self):
     vertstat(self, stat="range")
 
 
-def vertical_integration(self, thickness=None, depth_range=None):
+def vertical_integration(self, thickness=None, depth_range=None, fixed = None):
     """
     Calculate the vertically integrated sum over the water column
     This calculates the sum of the variable multiplied by the cell thickness
@@ -293,20 +343,57 @@ def vertical_integration(self, thickness=None, depth_range=None):
     Parameters
     -------------
     thickness: str or Dataset
+        This must be supplied when vertical levels vary spatially.
         One of: a variable, in the dataset, which contains the variable thicknesses; a .nc file which contains
         the thicknesses; or a Dataset that contains the thicknesses. Note: the .nc file or Dataset must only contain
         one variable.
     depth_range: list
         Set a depth range if desired. Should be of the form [min_depth, max_depth].
+    fixed : bool 
+        Define whether the vertical levels are the same in all spatial locations.
+        Set to True if they are, e.g. you have z-levels. If you have the likes of sigma-coordinates,
+        set this to True. 
 
     Examples
     ------------
 
-    If you wanted to sum of values across all vertical levels of every variable in a dataset, you would do this:
+    If you wanted to sum of values across all vertical levels of every variable in a dataset that has spatially fixed vertical levels, you would do this:
 
-    >>> ds.vertical_sum()
+    >>> ds.vertical_sum(fixed = True)
 
     """
+    if fixed is None and thickness is None:
+        raise ValueError("Please state if levels are fixed or provide thickness")
+
+    if fixed:
+        if version_above(cdo_version(), "2.0.0") is False:
+            raise ValueError("Please install CDO>2.0.0")
+        warnings.warn("Extracting vertical thickness from dataset level data")
+        var = list(self.contents.query("nlevels > 1").variable)[0]
+
+        ff = self[0]
+        command = f"cdo zaxisdes {ff}"
+        out = subprocess.Popen(
+                 command,
+                 shell=True,
+                 stdin=subprocess.PIPE,
+                 stdout=subprocess.PIPE,
+                 stderr=subprocess.STDOUT,
+             )
+        result, ignore = out.communicate()
+
+        if "bounds" not in result.decode("utf-8").lower():
+            raise ValueError("Vertical bounds info does not appear to be in the netCDF files, so thicknesses cannot be calculated for vertical integration!")
+
+        thickness = self.copy()
+        thickness.subset(time = 0, variable = var)
+        thickness.rename({var:"thickness"})
+        thickness.assign(thickness = lambda x: (isnan(x.thickness) == False) * level(x.thickness), drop = True)
+        thickness.assign(thickness = lambda x: thickness(x.thickness) + (x.thickness < x.thickness), drop = True)
+        thickness.run()
+    
+    if thickness is None:
+        raise ValueError("Please specify thickness")
 
     if type(depth_range) is list:
 
@@ -356,24 +443,29 @@ def vertical_integration(self, thickness=None, depth_range=None):
     # modify the depth if it is a list
     if type(depth_range) is list:
 
-        ds_thick.rename({thick_var: "thickness"})
-        ds_thick.run()
+        if thick_var != "thickness":
+            ds_thick.rename({thick_var: "thickness"})
+            ds_thick.run()
         ds_depth = ds_thick.copy()
         ds_depth.vertical_cumsum()
-        ds_depth.rename({"thickness": "depth"})
+        ds_depth.rename({"thickness": "depths"})
         ds_thick.append(ds_depth)
         ds_thick.merge()
-        ds_thick.assign(z_min=lambda x: x.depth - x.thickness)
+
+        ds_thick.assign(z_min=lambda x: x.depths - x.thickness)
         ds_thick.assign( z_min=lambda x: x.z_min * (x.z_min >= depth_range[0]) + depth_range[0] * (x.z_min < depth_range[0]))
-        ds_thick.assign( depth=lambda x: x.depth * (x.depth <= depth_range[1]) + depth_range[1] * (x.depth > depth_range[1]))
-        ds_thick.assign(thickness=lambda x: x.depth - x.z_min, drop=True)
+        ds_thick.assign( depths=lambda x: x.depths * (x.depths <= depth_range[1]) + depth_range[1] * (x.depths > depth_range[1]))
+        ds_thick.assign(thickness=lambda x: x.depths - x.z_min, drop=True)
         ds_thick.assign(thickness=lambda x: x.thickness * (x.thickness > 0), drop=True)
 
     self1.subset(variables=self1.contents.query("nlevels > 1").variable)
     if drop_this is not None:
         self1.drop(variables = drop_this)
 
+    ds_thick.run()
+    self1.run()
     self1.multiply(ds_thick)
+    self1.run()
     self1.vertical_sum()
     self1.run()
     del ds_thick
